

<section id="messages">
    <div class="flex-grid">
        <div class="message-container">
            <p id="message-p-tag"></p>
        </div>
    </div>

</section>


<section id="process-message">
    <div class="flex-grid two-column-grid--20-80">
        <div class="center process-container">
            <span class="loader" id="processing-code-loader"></span>
        </div>
     
        <div class="message-container">
            <p id="process-message-p-tag">Your code requested is being processed... </p>
        </div>
    </div>

</section>


