<section id="notification">
    <div class="flex-grid two-column-grid--20-80">
        <div class="message-check-message center margin-right-md notification-status"><i class="fa-solid fa-check"></i></div>
        <div class="notification">
            <p class="padding-top-sm padding-bottom-sm">This is a notifications</p>
        </div>
    </div>

</section>