{% extends "django_auth_recovery_codes/base.html" %}

{% load static %}

{% block title  %}Login{% endblock  %}


{% block content  %}
 <nav id="login-navigation" class="two-column-grid--40-60">
    <div class="head">
        {{ site_name }}
    </div>
    <div class="body">
        <p class="title">2FA Recovery codes backup codes</p>
     
    </div>
</nav>
<section id="login-user">
   
   {% include "django_auth_recovery_codes/partials/django_messages.html" %}
    {% include "django_auth_recovery_codes/partials/partial_forms/login_form.html" %}
</section>


<div class="copyright">
    <p class="center title" id="copryright">@copyright 2FA Recovery code backup</p>
</div>

{% endblock  %}



{% block extra_scripts %}

<script src="{% static 'django_recovery_codes/js/login/login.js' %}" defer type="module"></script>

{% endblock %}