{% extends "django_auth_recovery_codes/base.html" %}

{% load static %}

{% block title %} Dashboard {% endblock %}

{% block content %}

  {% include "django_auth_recovery_codes/partials/sidebar.html" %}

  <section id="recovery-dashboard" class="layout">

    <div class="container width-80">

      {% include "django_auth_recovery_codes/partials/navbar.html" %}

      <h1 id="page-title" class="font-weight-500 title margin-top-sm margin-bottom-sm">
        2FA Recovery Codes Dashboard
      </h1>

      {% include "django_auth_recovery_codes/partials/security_tips.html" %}
      {% include "django_auth_recovery_codes/partials/generate_codes.html" %}
      {% include "django_auth_recovery_codes/partials/view_codes.html" %}
      {% include "django_auth_recovery_codes/partials/test_setup.html" %}
      {% include "django_auth_recovery_codes/partials/invalidate_or_remove_codes.html" %}
      {% include "django_auth_recovery_codes/partials/view_batch_history.html" %}
      {% include "django_auth_recovery_codes/partials/pagination.html" %}
      {% include "django_auth_recovery_codes/partials/messages.html" %}
      {% include "django_auth_recovery_codes/partials/notify.html" %}

    </div>
  </section>

{% endblock %}

{% block extra_scripts %}

<script src="{% static 'django_recovery_codes/js/dashboard.js' %}" defer type="module"></script>
<script src="{% static 'django_recovery_codes/js/generateTable.js' %}" defer type="module"></script>
<script src="{% static 'django_recovery_codes/js/generateCodeActionButtons.js' %}" defer type="module"></script>
<script src="{% static 'django_recovery_codes/js/generateBatchHistoryCard.js' %}" defer type="module"></script>

{% endblock %}
