<div class="box-display bg-subtle-gray-with-padding border-danger margin-bottom-sm" role="region"
    aria-labelledby="page-title">
    <h1 class="medium-title text-red margin-bottom-md">
        <i class="fa-solid fa-lock" aria-hidden="true"></i> Security Tip
    </h1>

    <div class="margin-bottom-md">
        <p>Your <strong>recovery codes</strong> serve as backup access in case you lose your two-factor
            authentication (2FA) device or app.</p>
        <p><strong>Store your recovery codes securely</strong> and do not share them with anyone. Treat
            them
            like sensitive passwords.</p>
        <p>If you believe your codes have been exposed or lost, <strong>generate new recovery codes
            </strong> or <strong> remove or invalidate</strong> those codes immediately.</p>
        <p>Be cautious of phishing attempts any legitimate services will <em><strong>never</strong></em>
            ask you to provide
            your recovery codes.</p>
    </div>


    <span class="margin-top-lg warning"><i class="fa-solid fa-exclamation"></i> Warning</span>
    <p>Keeping your recovery codes safe ensures uninterrupted access to your account under all
        circumstances.</p>
</div>

<div id="security-tip" role="region" aria-labelledby="page-title">
    <h3 id="security-tip--title">🔐 Recovery Code Tips</h3>
    <ul id="security-tip--list">
        <li>You have recovery codes. Use them if you lose access to your two-factor authentication.</li>
        <li>Each recovery code can only be used once and once used, it becomes invalid.</li>
        <li>Top up your recovery codes when they approach expiry or run low.</li>
        <li>This ensures you can always regain access to your account.</li>
    </ul>
</div>