<form action="" method="post" id="invalidate-form" aria-labelledby="invalidate-form-label">
     
    <h1 id="invalidate-form-label" class="padding-top-md font-weight-500 medium-title">
        Invalidate code
    </h1>
    <hr class="dividor">

    <div class="form-inner padding-top-md">
        <div class="form-group flex-grid">
            <label for="invalidate-code-input">Code to invalidate</label>
            <input type="text" id="invalidate-code-input" name="invalidate_code" class="padding-md" maxlength="41" spellcheck="false"
                autocorrect="off"
                autocomplete="off"
                autocapitalize="none"
                minlength="41" placeholder="987A-CCSSS-9875-125468-14789D" required />
        </div>
        <div class="buttons">
            <button type="submit" class="btn-medium margin-top-sm padding-sm bg-red text-white"
                id="invalidate-code-btn">
                <span span class="loader" id="invalidate-code-loader"></span>
                <span id="invalidate-code-span-text"> <i class="fa-solid fa-ban"></i> Invalidate
                    code</span>
            </button>


        </div>
    </div>
</form>