from setuptools import setup, find_packages

setup(
    name="django-auth-recovery-codes",
    version="1.0.1",
    packages=find_packages(),
    include_package_data=True,
    description="A reusable Django app that extends any app allowing it to use 2FA recovery codes as backup to login.",
    author="Egbie Uku",
    author_email="egbieuku@hotmail.com",
    url="https://github.com/EgbieAndersonUku1/django_2fa_recovery_codes",
    classifiers=[
        "Framework :: Django",
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],

    python_requires=">=3.10,<3.14",

    install_requires=[
        "Django>=5.0",
        "django-picklefield>=3.3",
        "django-q2>=1.8.0",
        "django-email-sender>=2.0.5",
        "requests>=2.32",
        "reportlab>=4.4",
        "redis>=3.5",
        "pillow>=11.0",
        "arrow>=1.3",
        "beautifulsoup4>=4.13",
        "asgiref>=3.9",
        "soupsieve>=2.7",
        "sqlparse>=0.5",
        "typing_extensions>=4.14",
        "tzdata>=2025.2",
        "urllib3>=2.5",
        "certifi>=2025.8",
        "charset-normalizer>=3.4",
        "idna>=3.10",
        "six>=1.17",
        "wcwidth>=0.2",
        "blessed>=1.21",
        "jinxed>=1.3",
        "nh3>=0.3",
        "python-dateutil>=2.9",
    ],
    extras_require={
        "dev": [
            "black",
            "flake8",
            "pytest",
            "types-python-dateutil",
        ],
    },
)