{% if messages %}


{% for message in messages %}
    <div id="login-messages" class="center bg-green text-white bold margin-bottom-sm margin-top-sm">

          <p{% if message.tags %} class="{{ message.tags }} margin-top-sm margin-bottom-sm" {% endif %}>{{ message }}</p>
  
    </div>
  {% endfor %}



{% endif %}